@@ -1,10 +1,7 @@
 import dash
-import dash_html_components as html
-import dash_core_components as dcc
-import dash_bootstrap_components as dbc
-
-from dash.dependencies import Input, Output, State
+from dash import html, dcc, Input, Output, State
 from dash.exceptions import PreventUpdate
+import dash_bootstrap_components as dbc
 
 from .dashboard_components import *
 from .dashboard_tabs import *
