@@ -11,13 +11,9 @@ import numpy as np
 import pandas as pd
 
 import dash
-import dash_core_components as dcc
-import dash_bootstrap_components as dbc
-import dash_html_components as html
-import dash_table
-
-from dash.dependencies import Input, Output, State
+from dash import html, dcc, Input, Output, State, dash_table
 from dash.exceptions import PreventUpdate
+import dash_bootstrap_components as dbc
 
 from ..dashboard_methods import *
 from .. import to_html
