@@ -28,10 +28,10 @@ from importlib import import_module
 import socket
 
 import dash
-import dash_core_components as dcc
+from dash import html, dcc, Input, Output, State
+from dash.exceptions import PreventUpdate
+
 import dash_bootstrap_components as dbc
-import dash_html_components as html
-from dash.dependencies import Input, Output, State
 
 from . import to_html
 
